@@ -603,9 +603,7 @@ class MCTS(BaseStructureGenerator):
                                 cs=component, cutoff=self.cutoff, config=config, cfg_keys=[key])
             result = worker.start_transform_dataset(job)
 
-            # TODO remove again
-            if len(node.steps) < 4 and \
-                    result.status.value == StatusType.SUCCESS.value:
+            if result.status.value == StatusType.SUCCESS.value:
                 ds = Dataset(result.transformed_X, ds.y, ds.metric, ds.cutoff)
                 new_node.partial_config = PartialConfig(key, config, str(new_node.id), ds.meta_features)
                 new_node.ds = ds
